@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2004, 2005, 2007, 2009 John W. Eaton
+Copyright (C) 2004-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -26,6 +26,7 @@ along with Octave; see the file COPYING.  If not, see
 #include "intNDArray.h"
 #include "mx-op-decl.h"
 #include "oct-inttypes.h"
+#include "bsxfun-decl.h"
 
 typedef intNDArray<octave_int16> int16NDArray;
 
@@ -38,14 +39,12 @@ SND_BOOL_OP_DECLS (octave_int16, int16NDArray, OCTAVE_API)
 NDND_CMP_OP_DECLS (int16NDArray, int16NDArray, OCTAVE_API)
 NDND_BOOL_OP_DECLS (int16NDArray, int16NDArray, OCTAVE_API)
 
-MARRAY_FORWARD_DEFS (MArrayN, int16NDArray, octave_int16)
+MARRAY_FORWARD_DEFS (MArray, int16NDArray, octave_int16)
 
-MINMAX_DECLS (int16)
+MINMAX_DECLS (int16NDArray, octave_int16, OCTAVE_API)
+
+BSXFUN_STDOP_DECLS (int16NDArray, OCTAVE_API)
+BSXFUN_MIXED_INT_DECLS(int16NDArray, OCTAVE_API)
+BSXFUN_STDREL_DECLS (int16NDArray, OCTAVE_API)
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
