@@ -1,7 +1,7 @@
 // N-D Array  manipulations.
 /*
 
-Copyright (C) 2004, 2005, 2006, 2007, 2009 John W. Eaton
+Copyright (C) 2004-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -29,6 +29,8 @@ along with Octave; see the file COPYING.  If not, see
 #include "mx-op-defs.h"
 #include "intNDArray.cc"
 
+#include "bsxfun-defs.cc"
+
 template class OCTAVE_API intNDArray<octave_uint16>;
 
 template OCTAVE_API
@@ -39,19 +41,19 @@ template OCTAVE_API
 std::istream&
 operator >> (std::istream& is, intNDArray<octave_uint16>& a);
 
-NDS_CMP_OPS (uint16NDArray, , octave_uint16, )
-NDS_BOOL_OPS (uint16NDArray, octave_uint16, octave_uint16 (0))
+NDS_CMP_OPS (uint16NDArray, octave_uint16)
+NDS_BOOL_OPS (uint16NDArray, octave_uint16)
 
-SND_CMP_OPS (octave_uint16, , uint16NDArray, )
-SND_BOOL_OPS (octave_uint16, uint16NDArray, octave_uint16 (0))
+SND_CMP_OPS (octave_uint16, uint16NDArray)
+SND_BOOL_OPS (octave_uint16, uint16NDArray)
 
-NDND_CMP_OPS (uint16NDArray, , uint16NDArray, )
-NDND_BOOL_OPS (uint16NDArray, uint16NDArray, octave_uint16 (0))
+NDND_CMP_OPS (uint16NDArray, uint16NDArray)
+NDND_BOOL_OPS (uint16NDArray, uint16NDArray)
 
-MINMAX_FCNS (uint16)
+MINMAX_FCNS (uint16NDArray, octave_uint16)
 
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
+BSXFUN_STDOP_DEFS_MXLOOP (uint16NDArray)
+BSXFUN_STDREL_DEFS_MXLOOP (uint16NDArray)
+
+BSXFUN_OP_DEF_MXLOOP (pow, uint16NDArray, mx_inline_pow)
+BSXFUN_POW_MIXED_MXLOOP (uint16NDArray)
