@@ -1,5 +1,4 @@
-## Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2003, 2005,
-##               2007 Friedrich Leisch
+## Copyright (C) 1995-2012 Friedrich Leisch
 ##
 ## This file is part of Octave.
 ##
@@ -32,12 +31,12 @@
 ## Author: FL <Friedrich.Leisch@ci.tuwien.ac.at>
 ## Description: Spectral density estimation
 
-function retval = spectral_xdf (X, win, b)
+function retval = spectral_xdf (x, win, b)
 
-  xr = length (X);
+  xr = length (x);
 
-  if (columns (X) > 1)
-    X = X';
+  if (columns (x) > 1)
+    x = x';
   endif
 
   if (nargin < 3)
@@ -47,13 +46,13 @@ function retval = spectral_xdf (X, win, b)
   if (nargin == 1)
     w = triangle_sw (xr, b);
   else
-    win = str2func (strcat (win, "_sw"));
+    win = str2func (cstrcat (win, "_sw"));
     w = feval (win, xr, b);
   endif
 
-  X = X - sum (X) / xr;
+  x = x - sum (x) / xr;
 
-  retval = (abs (fft (X)) / xr).^2;
+  retval = (abs (fft (x)) / xr).^2;
   retval = real (ifft (fft(retval) .* fft(w)));
 
   retval = [(zeros (xr, 1)), retval];
@@ -61,10 +60,3 @@ function retval = spectral_xdf (X, win, b)
 
 endfunction
 
-
-
-
-
-
-
-
