@@ -1,7 +1,7 @@
 /*
 
-Copyright (C) 2004, 2005, 2006, 2007, 2009 David Bateman
-Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Andy Adler
+Copyright (C) 2004-2012 David Bateman
+Copyright (C) 1998-2004 Andy Adler
 
 This file is part of Octave.
 
@@ -76,7 +76,7 @@ DEFBINOP (ldiv, sparse_matrix, complex)
       double d = v1.scalar_value ();
 
       if (d == 0.0)
-	gripe_divide_by_zero ();
+        gripe_divide_by_zero ();
 
       return octave_value (SparseComplexMatrix (1, 1, v2.complex_value () / d));
     }
@@ -121,8 +121,8 @@ DEFBINOP (el_ldiv, sparse_matrix, complex)
 {
   CAST_BINOP_ARGS (const octave_sparse_matrix&, const octave_complex&);
 
-  return octave_value (x_el_div (v2.complex_value (), 
-				 v1.sparse_matrix_value ()));
+  return octave_value (x_el_div (v2.complex_value (),
+                                 v1.sparse_matrix_value ()));
 }
 
 DEFBINOP_FN (el_and, sparse_matrix, complex, mx_el_and)
@@ -161,11 +161,5 @@ install_sm_cs_ops (void)
   INSTALL_CATOP (octave_sparse_matrix, octave_complex, sm_cs);
 
   INSTALL_ASSIGNCONV (octave_sparse_matrix, octave_complex,
-		      octave_sparse_complex_matrix);
+                      octave_sparse_complex_matrix);
 }
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
