@@ -1,7 +1,6 @@
 /*
 
-Copyright (C) 1996, 1997, 1998, 2000, 2002, 2003, 2004, 2005, 2006,
-              2007, 2008 John W. Eaton
+Copyright (C) 1996-2012 John W. Eaton
 
 This file is part of Octave.
 
@@ -90,7 +89,7 @@ octave_scalar::do_index_op (const octave_value_list& idx, bool resize_ok)
   return tmp.do_index_op (idx, resize_ok);
 }
 
-octave_value 
+octave_value
 octave_scalar::resize (const dim_vector& dv, bool fill) const
 {
   if (fill)
@@ -98,7 +97,7 @@ octave_scalar::resize (const dim_vector& dv, bool fill) const
       NDArray retval (dv, NDArray::resize_fill_value());
 
       if (dv.numel ())
-	retval(0) = scalar;
+        retval(0) = scalar;
 
       return retval;
     }
@@ -107,7 +106,7 @@ octave_scalar::resize (const dim_vector& dv, bool fill) const
       NDArray retval (dv);
 
       if (dv.numel ())
-	retval(0) = scalar;
+        retval(0) = scalar;
 
       return retval;
     }
@@ -119,19 +118,19 @@ octave_scalar::convert_to_str_internal (bool, bool, char type) const
   octave_value retval;
 
   if (xisnan (scalar))
-    ::error ("invalid conversion from NaN to character");
+    gripe_nan_to_character_conversion ();
   else
     {
       int ival = NINT (scalar);
 
       if (ival < 0 || ival > UCHAR_MAX)
-	{
-	  // FIXME -- is there something better we could do?
+        {
+          // FIXME -- is there something better we could do?
 
-	  ival = 0;
+          ival = 0;
 
-	  ::warning ("range error for conversion to character value");
-	}
+          ::warning ("range error for conversion to character value");
+        }
 
       retval = octave_value (std::string (1, static_cast<char> (ival)), type);
     }
@@ -139,7 +138,7 @@ octave_scalar::convert_to_str_internal (bool, bool, char type) const
   return retval;
 }
 
-bool 
+bool
 octave_scalar::save_ascii (std::ostream& os)
 {
   double d = double_value ();
@@ -151,10 +150,10 @@ octave_scalar::save_ascii (std::ostream& os)
   return true;
 }
 
-bool 
+bool
 octave_scalar::load_ascii (std::istream& is)
 {
-  scalar = octave_read_double (is);
+  scalar = octave_read_value<double> (is);
   if (!is)
     {
       error ("load: failed to load scalar constant");
@@ -164,7 +163,7 @@ octave_scalar::load_ascii (std::istream& is)
   return true;
 }
 
-bool 
+bool
 octave_scalar::save_binary (std::ostream& os, bool& /* save_as_floats */)
 {
   char tmp = LS_DOUBLE;
@@ -175,9 +174,9 @@ octave_scalar::save_binary (std::ostream& os, bool& /* save_as_floats */)
   return true;
 }
 
-bool 
+bool
 octave_scalar::load_binary (std::istream& is, bool swap,
-			    oct_mach_info::float_format fmt)
+                            oct_mach_info::float_format fmt)
 {
   char tmp;
   if (! is.read (reinterpret_cast<char *> (&tmp), 1))
@@ -196,7 +195,7 @@ octave_scalar::load_binary (std::istream& is, bool swap,
 
 bool
 octave_scalar::save_hdf5 (hid_t loc_id, const char *name,
-			  bool /* save_as_floats */)
+                          bool /* save_as_floats */)
 {
   hsize_t dimens[3];
   hid_t space_hid = -1, data_hid = -1;
@@ -205,9 +204,14 @@ octave_scalar::save_hdf5 (hid_t loc_id, const char *name,
   space_hid = H5Screate_simple (0, dimens, 0);
   if (space_hid < 0) return false;
 
-  data_hid = H5Dcreate (loc_id, name, H5T_NATIVE_DOUBLE, space_hid, 
-			H5P_DEFAULT);
-  if (data_hid < 0) 
+#if HAVE_HDF5_18
+  data_hid = H5Dcreate (loc_id, name, H5T_NATIVE_DOUBLE, space_hid,
+                        H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+#else
+  data_hid = H5Dcreate (loc_id, name, H5T_NATIVE_DOUBLE, space_hid,
+                        H5P_DEFAULT);
+#endif
+  if (data_hid < 0)
     {
       H5Sclose (space_hid);
       return false;
@@ -215,7 +219,7 @@ octave_scalar::save_hdf5 (hid_t loc_id, const char *name,
 
   double tmp = double_value ();
   retval = H5Dwrite (data_hid, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL,
-		     H5P_DEFAULT, &tmp) >= 0;
+                     H5P_DEFAULT, &tmp) >= 0;
 
   H5Dclose (data_hid);
   H5Sclose (space_hid);
@@ -224,24 +228,27 @@ octave_scalar::save_hdf5 (hid_t loc_id, const char *name,
 }
 
 bool
-octave_scalar::load_hdf5 (hid_t loc_id, const char *name,
-			  bool /* have_h5giterate_bug */)
+octave_scalar::load_hdf5 (hid_t loc_id, const char *name)
 {
+#if HAVE_HDF5_18
+  hid_t data_hid = H5Dopen (loc_id, name, H5P_DEFAULT);
+#else
   hid_t data_hid = H5Dopen (loc_id, name);
+#endif
   hid_t space_id = H5Dget_space (data_hid);
 
   hsize_t rank = H5Sget_simple_extent_ndims (space_id);
 
   if (rank != 0)
-    { 
+    {
       H5Dclose (data_hid);
       return false;
     }
 
   double dtmp;
-  if (H5Dread (data_hid, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL, 
-	       H5P_DEFAULT, &dtmp) < 0)
-    { 
+  if (H5Dread (data_hid, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL,
+               H5P_DEFAULT, &dtmp) < 0)
+    {
       H5Dclose (data_hid);
       return false;
     }
@@ -267,70 +274,88 @@ octave_scalar::as_mxArray (void) const
   return retval;
 }
 
-#define SCALAR_MAPPER(MAP, FCN) \
-  octave_value \
-  octave_scalar::MAP (void) const \
-  { \
-    return octave_value (FCN (scalar)); \
-  }
-
-#define CD_SCALAR_MAPPER(MAP, RFCN, CFCN, L1, L2) \
-  octave_value \
-  octave_scalar::MAP (void) const \
-  { \
-    return (scalar < L1 || scalar > L2 \
-            ? octave_value (CFCN (Complex (scalar))) \
-	    : octave_value (RFCN (scalar))); \
-  }
-
-static double
-xconj (double x)
+octave_value
+octave_scalar::map (unary_mapper_t umap) const
 {
-  return x;
+  switch (umap)
+    {
+    case umap_imag:
+      return 0.0;
+
+    case umap_real:
+    case umap_conj:
+      return scalar;
+
+#define SCALAR_MAPPER(UMAP, FCN) \
+    case umap_ ## UMAP: \
+      return octave_value (FCN (scalar))
+
+      SCALAR_MAPPER (abs, ::fabs);
+      SCALAR_MAPPER (acos, rc_acos);
+      SCALAR_MAPPER (acosh, rc_acosh);
+      SCALAR_MAPPER (angle, ::arg);
+      SCALAR_MAPPER (arg, ::arg);
+      SCALAR_MAPPER (asin, rc_asin);
+      SCALAR_MAPPER (asinh, ::asinh);
+      SCALAR_MAPPER (atan, ::atan);
+      SCALAR_MAPPER (atanh, rc_atanh);
+      SCALAR_MAPPER (erf, ::erf);
+      SCALAR_MAPPER (erfinv, ::erfinv);
+      SCALAR_MAPPER (erfc, ::erfc);
+      SCALAR_MAPPER (erfcx, ::erfcx);
+      SCALAR_MAPPER (gamma, xgamma);
+      SCALAR_MAPPER (lgamma, rc_lgamma);
+      SCALAR_MAPPER (cbrt, ::cbrt);
+      SCALAR_MAPPER (ceil, ::ceil);
+      SCALAR_MAPPER (cos, ::cos);
+      SCALAR_MAPPER (cosh, ::cosh);
+      SCALAR_MAPPER (exp, ::exp);
+      SCALAR_MAPPER (expm1, ::expm1);
+      SCALAR_MAPPER (fix, ::fix);
+      SCALAR_MAPPER (floor, gnulib::floor);
+      SCALAR_MAPPER (log, rc_log);
+      SCALAR_MAPPER (log2, rc_log2);
+      SCALAR_MAPPER (log10, rc_log10);
+      SCALAR_MAPPER (log1p, rc_log1p);
+      SCALAR_MAPPER (round, xround);
+      SCALAR_MAPPER (roundb, xroundb);
+      SCALAR_MAPPER (signum, ::signum);
+      SCALAR_MAPPER (sin, ::sin);
+      SCALAR_MAPPER (sinh, ::sinh);
+      SCALAR_MAPPER (sqrt, rc_sqrt);
+      SCALAR_MAPPER (tan, ::tan);
+      SCALAR_MAPPER (tanh, ::tanh);
+      SCALAR_MAPPER (finite, xfinite);
+      SCALAR_MAPPER (isinf, xisinf);
+      SCALAR_MAPPER (isna, octave_is_NA);
+      SCALAR_MAPPER (isnan, xisnan);
+
+    default:
+      if (umap >= umap_xisalnum && umap <= umap_xtoupper)
+        {
+          octave_value str_conv = convert_to_str (true, true);
+          return error_state ? octave_value () : str_conv.map (umap);
+        }
+      else
+        return octave_base_value::map (umap);
+    }
 }
 
-SCALAR_MAPPER (erf, ::erf)
-SCALAR_MAPPER (erfc, ::erfc)
-SCALAR_MAPPER (gamma, xgamma)
-CD_SCALAR_MAPPER (lgamma, xlgamma, xlgamma, 0.0, octave_Inf)
-SCALAR_MAPPER (abs, ::fabs)
-CD_SCALAR_MAPPER (acos, ::acos, ::acos, -1.0, 1.0)
-CD_SCALAR_MAPPER (acosh, ::acosh, ::acosh, 1.0, octave_Inf)
-SCALAR_MAPPER (angle, ::arg)
-SCALAR_MAPPER (arg, ::arg)
-CD_SCALAR_MAPPER (asin, ::asin, ::asin, -1.0, 1.0)
-SCALAR_MAPPER (asinh, ::asinh)
-SCALAR_MAPPER (atan, ::atan)
-CD_SCALAR_MAPPER (atanh, ::atanh, ::atanh, -1.0, 1.0)
-SCALAR_MAPPER (ceil, ::ceil)
-SCALAR_MAPPER (conj, xconj)
-SCALAR_MAPPER (cos, ::cos)
-SCALAR_MAPPER (cosh, ::cosh)
-SCALAR_MAPPER (exp, ::exp)
-SCALAR_MAPPER (expm1, ::expm1)
-SCALAR_MAPPER (fix, ::fix)
-SCALAR_MAPPER (floor, ::floor)
-SCALAR_MAPPER (imag, ::imag)
-CD_SCALAR_MAPPER (log, ::log, std::log, 0.0, octave_Inf)
-CD_SCALAR_MAPPER (log2, xlog2, xlog2, 0.0, octave_Inf)
-CD_SCALAR_MAPPER (log10, ::log10, std::log10, 0.0, octave_Inf)
-CD_SCALAR_MAPPER (log1p, ::log1p, ::log1p, -1.0, octave_Inf)
-SCALAR_MAPPER (real, ::real)
-SCALAR_MAPPER (round, xround)
-SCALAR_MAPPER (roundb, xroundb)
-SCALAR_MAPPER (signum, ::signum)
-SCALAR_MAPPER (sin, ::sin)
-SCALAR_MAPPER (sinh, ::sinh)
-CD_SCALAR_MAPPER (sqrt, ::sqrt, std::sqrt, 0.0, octave_Inf)
-SCALAR_MAPPER (tan, ::tan)
-SCALAR_MAPPER (tanh, ::tanh)
-SCALAR_MAPPER (finite, xfinite)
-SCALAR_MAPPER (isinf, xisinf)
-SCALAR_MAPPER (isna, octave_is_NA)
-SCALAR_MAPPER (isnan, xisnan)
+bool
+octave_scalar::fast_elem_insert_self (void *where, builtin_type_t btyp) const
+{
 
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
+  // Support inline real->complex conversion.
+  if (btyp == btyp_double)
+    {
+      *(reinterpret_cast<double *>(where)) = scalar;
+      return true;
+    }
+  else if (btyp == btyp_complex)
+    {
+      *(reinterpret_cast<Complex *>(where)) = scalar;
+      return true;
+    }
+  else
+    return false;
+}
